# -*- coding: utf-8 -*-
from faker.providers import BaseProvider
from random import randint
from .vehicle_dict import vehicles

class VehicleProvider(BaseProvider):
    """
    A Provider for vehicle related test data.

    >>> from faker import Faker
    >>> from faker_vehicle import VehicleProvider
    >>> fake = Faker()
    >>> fake.add_provider(VehicleProvider)
    """

    def vehicle_object(self):
        # Returns a random vehicle dict example: {"Year": 2008, "Make": "Jeep", "Model": "Wrangler", "Category": "SUV"}
        randItem = randint(1,len(vehicles))
        veh = vehicles[randItem]
        return veh

    def vehicle_year_make_model(self):
        # Returns Year Make Model example: "1997 Nissan 240SX"
        veh = self.vehicle_object()
        year = veh.get('Year')
        make = veh.get('Make')
        model = veh.get('Model')
        return str(year) + ' ' + make + ' ' + model

    def vehicle_year_make_model_cat(self):
        # Returns Year Make Model Cat example: 2017 GMC Sierra 1500 Double Cab (Pickup)
        veh = self.vehicle_object()
        year = veh.get('Year')
        make = veh.get('Make')
        model = veh.get('Model')
        cat = veh.get('Category')
        return str(year) + ' ' + make + ' ' + model + ' (' + cat + ')'

    def vehicle_make_model(self):
        # Returns Make Model example: Audi Q7
        veh = self.vehicle_object()
        make = veh.get('Make')
        model = veh.get('Model')
        return make + ' ' + model

    def vehicle_make(self):
        # Returns Make example: Lincoln
        veh = self.vehicle_object()
        return veh.get('Make')

    def vehicle_year(self):
        # Returns Year example: 1999
        veh = self.vehicle_object()
        return str(veh.get('Year'))

    def vehicle_model(self):
        # Returns Model example: Frontier King Cab
        veh = self.vehicle_object()
        return veh.get('Model')

    def vehicle_category(self):
        # Returns Category example: SUV
        veh = self.vehicle_object()
        return veh.get('Category')


#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
import io

from setuptools import setup

here = os.path.abspath(os.path.dirname(__file__))
README = io.open(os.path.join(here, 'README.rst'), encoding="utf8").read()

version = '0.1.0'

tests_require = [
    'pytest',
    'pytest-cov',
    'pytest-flakes',
    'pytest-pep8',
]

# this module can be zip-safe if the zipimporter implements iter_modules or if
# pkgutil.iter_importer_modules has registered a dispatch for the zipimporter.
try:
    import pkgutil
    import zipimport
    zip_safe = hasattr(zipimport.zipimporter, "iter_modules") or \
        zipimport.zipimporter in pkgutil.iter_importer_modules.registry.keys()
except (ImportError, AttributeError):
    zip_safe = False

setup(
    name='faker_vehicle',
    version=version,
    description="Vehicle related Provider for the Faker Python package.",
    long_description=README,
    classifiers=[
        # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
        'Development Status :: 4 - Beta',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Software Development :: Testing',
        'Topic :: Utilities',
        'License :: OSI Approved :: Apache Software License'
    ],
    keywords='faker vehicle test data',
    author='kennethwsmith',
    author_email='kennethwsmith+fakerveh@gmail.com',
    url='https://github.com/kennethwsmith/faker_vehicle',
    license='Apache License, Version 2.0',
    package_dir={'faker_vehicle': 'src/vehicle'},
    packages=['faker_vehicle'],
    platforms=['any'],
    test_suite='pytest',
    zip_safe=zip_safe,
    setup_requires=['pytest-runner'],
    tests_require=tests_require,
    install_requires=['faker'],
    extras_require={'test': tests_require},
)
